

SLAQuery
=====================

.. currentmodule:: pyvo.dal.sla

.. autoclass:: SLAQuery
   :show-inheritance:

   
     
   

   
   

   .. rubric:: Attributes Summary

   .. autosummary::
   
      ~SLAQuery.format
      ~SLAQuery.std_parameters
      ~SLAQuery.wavelength

   
   

   
   
   

   
   

   .. rubric:: Attributes Documentation

   
   .. autoattribute:: format
   .. autoattribute:: std_parameters
   .. autoattribute:: wavelength

   
   

   
   
   